function [x i X] = gradmulti(grad, hesse, x0, eps, nmax)
% Two-variable minimization by Newton's method
%
% Input:
%   grad  - function to compute gradient vector
%   hesse - function to compute Hessian
%   x0 - vector of initial values
%   eps   - stopping criterion, step size
%   nmax  - stopping criterion, maximum number of iterations
%
% Output:
%   x - solution vector
%   i - number of iterations
%   X - matrix of iteration steps

x1 = x0 - pinv(hesse(x0))*grad(x0);
i=1;
X=[x0 x1];

% Stopping criteria:
% 1., step size is smaller than 'eps', or
% 2., maximum number of iterations, 'nmax' is reached
while and(norm(x1 - x0) > eps, i < nmax)
	x0 = x1;
	x1 = x0 - pinv(hesse(x0))*grad(x0);
	i = i + 1;
	X = [X x1];
end
x = x1;

